#!/bin/sh
#
# Package: auto-pilot
# Charles P. Wright <cwright@cs.sunysb.edu>
# Erez Zadok <ezk@cs.sunysb.edu>
# Copyright (c) 2001-2006 Stony Brook University

# Use common settings

source commonsettings || exit $?

if [ -z "$TESTDIR" ] ; then
	echo "You must specify the TESTDIR as an environment variable."
	exit 1
fi
if [ ! -d "$TESTDIR" ] ; then
	echo "TESTDIR ($TESTDIR) is not a directory."
	exit 1
fi

set_default THREADS 1
set_default POSTMARKDIR $TESTDIR/postmark/$APTHREAD
set_default TRANSACTIONS 200000
set_default MYTRANSACTIONS $(($TRANSACTIONS / $THREADS))
set_default INITFILES $((TRANSACTIONS / 10))
set_default MYINITFILES $((INITFILES / $THREADS))
set_default SUBDIRS $((INITFILES / 100))
set_default MYSUBDIRS $((SUBDIRS / $THREADS))
set_default MINSIZE 512
set_default MAXSIZE 10240
set_default SEED 42
set_default READSIZE 4096
set_default WRITESIZE 4096
set_default BUFFERING false
set_default READBIAS 5
set_default CREATEBIAS 5

mkdir -p $POSTMARKDIR
CONFIG="/tmp/postmark_config-$$"

cat <<PM_CONFIG > $CONFIG
set size $MINSIZE $MAXSIZE
set number $MYINITFILES
set seed $SEED
set transactions $MYTRANSACTIONS
set location $POSTMARKDIR
set subdirectories $MYSUBDIRS
set read $READSIZE
set write $WRITESIZE
set buffering $BUFFERING
set bias read $READBIAS
set bias create $CREATEBIAS
PM_CONFIG

ap_hook pmextra $CONFIG

cat <<PM_CONFIG >> $CONFIG
show
run
quit
PM_CONFIG

#run the benchmark
cat "$CONFIG"
semdec $APIPCKEY
ap_measure postmark "$CONFIG"
rm -f "$CONFIG"

cd ${TESTDIR}
rm -rf ${POSTMARKDIR}

exit 0
